@@ -46,7 +46,12 @@ poscar_path = os.path.join(
     "POSCAR",
 )
 
-
+cif_example = os.path.join(
+    os.path.dirname(__file__),
+    "1000052.cif",
+)
+def test_from_cif():
+    a=Atoms.from_cif(cif_example)
 def test_basic_atoms():
 
     box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
@@ -81,7 +86,7 @@ def test_basic_atoms():
     assert round(prim.raw_distance_matrix[0][1], 2) == round(
         4.42386329832851, 2
     )
-
+    print(prim.raw_angle_matrix)
     d = Si.to_dict()
     new_at = Atoms.from_dict(d)
     angs_a = d["angles"][0]
@@ -90,6 +95,11 @@ def test_basic_atoms():
         coords=d["coords"],
         elements=d["elements"],
     ).density
+    Si_xyz=Si.get_xyz_string
+    Si.write_xyz(filename="atoms.xyz")
+    tmp=Atoms.from_xyz(filename="atoms.xyz")
+    cmd='rm atoms.xyz'
+    os.system(cmd)
     Si.center_around_origin()
     # print ('scell_nat', Si_2)
     assert (
@@ -151,6 +161,7 @@ def test_basic_atoms():
     assert m1.lattice_mat[2][2] == 36.158933360000006
     filename = "atoms.cif"
     m1.write_cif(filename)
+    a=Atoms.from_cif(filename)
     filename = "POSCAR"
     m1.write_poscar(filename)
     m2 = Atoms.from_poscar(filename)
